# @summary
#   Describe what this class do!
#
#   Detailed summary info if suitable
#
#
class aes::auth_keydb {
  $keydb_user = auth_keydb
  $keydb_group = $keydb_user
  $keydb_home = "/srv/${keydb_user}"
  $keydb_service = 'aes_auth_keydb'

  # Figure out which certificate to use based on the hostname.
  if $facts[fqdn] == 'aes.edu.liu.se' {
    $server_type = 'production'
  } elsif $facts[fqdn] == 'aes-devel.edu.liu.se' {
    $server_type = 'devel'
  } else {
    $server_type = undef
  }

  user { $keydb_user :
    ensure     => present,
    home       => $keydb_home,
    comment    => 'Authentication server for AES',
    managehome => false,
    membership => inclusive,
    groups     => ['aes_local_auth'],
    system     => true,
    shell      => '/sbin/nologin',
  }

  file { $keydb_home :
    ensure => directory,
    owner  => $keydb_user,
    group  => $keydb_group,
    mode   => '0755',
  }

  file { "/etc/systemd/system/${keydb_service}.service" :
    ensure => file,
    owner  => root,
    group  => root,
    mode   => '0644',
    source => "puppet:///modules/${module_name}/auth/keydb.service",
  }

  file { "${keydb_home}/on_update.sh" :
    ensure => file,
    owner  => root,
    group  => root,
    mode   => '0700',
    source => "puppet:///modules/${module_name}/auth/on_update_keydb.sh",
  }

  exec { 'update-keydb-repo' :
    command     => "/opt/utils/update_repo.sh ${keydb_home}/src https://oauth2:F-agHaRXCdyFy38q4c-N@gitlab.liu.se/upp-aes/communication.git ${server_type}",
    environment => ["REPO_USER=${keydb_user}", "REPO_GROUP=${keydb_group}", "REPO_ON_UPDATE=${keydb_home}/on_update.sh"],
    # This command will need to run "on_update" as root in order to restart the service.
    user        => root,
    group       => root,
    cwd         => $keydb_home,
    require     => File["${keydb_home}/on_update.sh"],
  }

  service { $keydb_service :
    ensure => 'running',
    enable => true,
  }

  # These are temporary until the AdmC database is up and running.

  file { '/etc/systemd/system/aes_temp_userdb.service' :
    ensure => file,
    owner  => root,
    group  => root,
    mode   => '0644',
    source => "puppet:///modules/${module_name}/auth/temp_userdb.service",
  }

  service { 'aes_temp_userdb' :
    ensure => 'running',
  }
}
